#!/bin/bash
###############################################################
#                      HELP  
# before starting verify:
# 1. Conversion options files have the correct references to 
#    the module name:
# - cvs2bzr-MODULE.options
# - cvs2bzr-MODULE-tmp.options
# 2. There are no bzr repositories in the ./bzrrepo with name:
#  - MODULENAME
#  - MODULENAME-tmp
# 3. Delete backup *.fi files:
#  - ./cvs2svn2.4.0/cvs2svn-tmp/MODULENAME.fi
#  - ./cvs2svn2.4.0/cvs2svn-tmp/MODULENAME-tmp.fi
# 4. Delete ./work directory:
# 5. Create the cvs2-svn2.4.0/cvs2svn-tmp directory if needed
###############################################################

clear

oldcvsroot=$CVSROOT
module=""
moduletmp=""
pwd=$PWD

export CVSROOT=$PWD/cvsrepo
bzrroot=$PWD/bzrrepo
cvsroot=$CVSROOT
echo "CVSROOT = $CVSROOT"
echo "BZRROOT = $bzrroot"

# Test if the module name is passed as a parameter
if [ $# != 1 ] ; then
   echo "Format:"
   echo "convert module_name"
   exit 1
else
   module=$1
   moduletmp=$1-tmp
fi

###############################################################
#                      STAGE 1                                #
#                                                             #
# convert from cvs into bzr repo "modulename" with no tags    #
#                                                             #
###############################################################

# Test if the module exists in the repository
if [ ! -d $cvsroot/$module ]
then
   echo "$cvsroot/$module does not exist.";
   exit 1
fi

# Test if the cvs2bzr option file is in place
if [ ! -f cvs2bzr-$module.options ] ;then
   echo "The ./cvs2bzr-$module.options file does not exist"
   exit 1
fi

# If there is a bazaar repo then stop
if [ -d $bzrroot/$module ] ;then
   echo "The $bzrroot/$module directory already exists"
   exit 1
fi

# Create the bazaar repository
mkdir $bzrroot/$module
cd $bzrroot
bzr init-repo $module
bzr init $module/trunk
cd $pwd

# TODO PREPROCESSING
echo "Preprocessing ..."

# Starting conversion
echo "Starting conversion ..."

# Export from CVS in fi
cd $pwd/cvs2svn-2.4.0
./cvs2bzr --options=../cvs2bzr-$module-notags.options
#          --username $USER \          
#          --dumpfile ../tmp/$module.fi \
##         $cvsroot/$module/

# make a backup
cp -f ./cvs2svn-tmp/dumpfile.fi ./cvs2svn-tmp/$module.fi

# Import from fi in BZR
bzr fast-import ./cvs2svn-tmp/dumpfile.fi $bzrroot/$module



###############################################################
#                      STAGE 2                                #
#                                                             #
# convert from cvs into bzr repo "modulename-tmp with tags    #
#                                                             #
###############################################################
cd $pwd

# Test if the cvs2bzr option file is in place
if [ ! -f cvs2bzr-$moduletmp.options ] ;then
   echo "The ./cvs2bzr-$moduletmp.options file does not exist"
   exit 1
fi

# If there is a bazaar repo then stop
if [ -d $bzrroot/$moduletmp ] ;then
   echo "The $bzrroot/$moduletmp directory already exists"
   exit 1
fi

# Create the bazaar repository
mkdir $bzrroot/$moduletmp
cd $bzrroot
bzr init-repo $moduletmp
bzr init $moduletmp/trunk
cd $pwd

# Starting conversion
echo "Starting conversion for tmp repository ..."

# Export from CVS in fi
cd $pwd/cvs2svn-2.4.0
./cvs2bzr --options=../cvs2bzr-$moduletmp.options

# make a backup
cp -f ./cvs2svn-tmp/dumpfile.fi ./cvs2svn-tmp/$moduletmp.fi

# Import from fi in BZR
bzr fast-import ./cvs2svn-tmp/dumpfile.fi $bzrroot/$moduletmp

# TODO POSTPROCESSING
echo "Postprocessing ..."

###############################################################
#                      STAGE 3                                #
#                                                             #
# extract tags and timestamps from tmp repository             #
# results will be in the tags directory                       #
# - tags.txt                                                  #
# - ts.txt                                                    #
###############################################################

mkdir $pwd/work

# Extract tags
echo "Extracting tags ..."
cd $bzrroot/$moduletmp/trunk

bzr tags > $pwd/work/tags.txt

# Extract timestamps
cd $bzrroot/$moduletmp/trunk
echo "Extracting timestamps.  Wait 3-4 minutes ..."
bzr tags | awk '{printf "%s%s", $1," "} {system( "bzr log -r"  $1 " | grep timestamp")}' $pwd/work/tags.txt > $pwd/work/ts.txt

###############################################################
#                      STAGE 4                                #
#                                                             #
# apply tags to MODULENAME bzr repository                     #
# based on timestamps from ts.txt                             #
#                                                             #
###############################################################

cd $bzrroot/$module/trunk
awk '{print "Aplly TAG: " $1} {system( "bzr tag -r date:"$4","$5" "$1 )}' $pwd/work/ts.txt







