#!/bin/bash
clear

oldcvsroot=$CVSROOT
module=""
tag=""
pwd=$PWD

export CVSROOT=$PWD/cvsrepo
bzrroot=$PWD/bzrrepo
cvsroot=$CVSROOT
echo "CVSROOT = $CVSROOT"
echo "BZRROOT = $bzrroot"

# Run for all tags
if [ $# = 1 -a $1="all" ] ; then 
  #awk -v MODN=$module '{system( "./verify.sh " MODN " " $1 )}' $pwd/work/tags.txt
  awk -v MODN=$module '{system( "./verify.sh p2j" $1 )}' $pwd/work/tags.txt  
fi

# Run for a single tag
if [ $# != 2 ] ; then
   echo "Syntax: verify.sh module_name tag_name"
   echo "      : verify.sh all"
   exit 1
else
   module=$1
   tag=$2
fi



###############################################################
#                      STAGE 1                                #
#                                                             #
# checkout from CVS and BZR in v-cvs and v-bzr directories    #
#                                                             #
###############################################################

# Test if the CVS module
if [ ! -d $cvsroot/$module ]
then
   echo "$cvsroot/$module does not exist.";
   exit 1
fi

# Test BZR module
if [ ! -d $bzrroot/$module ] ;then
   echo "$bzrroot/$module does not exist."
   exit 1
fi

# Checkout from CVS
rm -fr $pwd/work/v-cvs
mkdir $pwd/work/v-cvs
cd $pwd/work/v-cvs

cvs co -r $tag $module

# Checkout from BZR
rm -fr $pwd/work/v-bzr
mkdir $pwd/work/v-bzr
mkdir $pwd/work/v-bzr/$module
cd $pwd/work/v-bzr/$module

bzr checkout -r tag:$tag $bzrroot/$module/trunk .

# delete CVS and .bzr files
cd $pwd/work/v-cvs
find . -name 'CVS' | xargs rm -r 

cd $pwd/work/v-bzr/$module
rm -rf .bzr

###############################################################
#                      STAGE 2                                #
#                                                             #
# diff all files from v-cvs and v-bzr directories             #
#                                                             #
###############################################################
mkdir -p $pwd/work/v-diff
rm -f $pwd/work/v-diff/$tag.diff

cd $pwd/work
diff -rq v-cvs/p2j v-bzr/p2j/ > $pwd/work/v-diff/$tag.diff

# Test if there are diffs
if [ -s $pwd/work/v-diff/$tag.diff ] 
then
   echo "Tag $tag -> Not identical."
else
   echo "Tag $tag -> Identical."
fi
