#!/bin/bash
clear

oldcvsroot=$CVSROOT
module=""
tag=""
pwd=$PWD

export CVSROOT=$PWD/cvsrepo
bzrroot=$PWD/bzrrepo
cvsroot=$CVSROOT
echo "CVSROOT = $CVSROOT"
echo "BZRROOT = $bzrroot"

if [ $# != 1 ] ; then
   echo "Syntax: verifyall.sh module_name"   
   exit 1
else
   module=$1
fi

echo > diff.log
for line in $(awk '{print $1}' $pwd/work/tags.txt); do
   echo "tag: " $line
   tag=$line

   # Test CVS module
   if [ ! -d $cvsroot/$module ] ;then
      echo "$cvsroot/$module does not exist.";
      exit 1
   fi

   # Test BZR module
   if [ ! -d $bzrroot/$module ] ;then
      echo "$bzrroot/$module does not exist."
      exit 1
   fi

   # Checkout from CVS
   rm -fr $pwd/work/v-cvs
   mkdir $pwd/work/v-cvs
   cd $pwd/work/v-cvs

   cvs co -r $tag $module

   # Checkout from BZR
   rm -fr $pwd/work/v-bzr
   mkdir $pwd/work/v-bzr
   mkdir $pwd/work/v-bzr/$module
   cd $pwd/work/v-bzr/$module

   bzr checkout -r tag:$tag $bzrroot/$module/trunk .

   # delete CVS and .bzr files
   cd $pwd/work/v-cvs
   find . -name 'CVS' | xargs rm -r 

   cd $pwd/work/v-bzr/$module
   rm -rf .bzr

   # Stage 2: diff all files from v-cvs and v-bzr directories

   mkdir -p $pwd/work/v-diff
   rm -f $pwd/work/v-diff/$tag.diff

   cd $pwd/work
   diff -rq v-cvs/p2j v-bzr/p2j/ > $pwd/work/v-diff/$tag.diff

   # Test if there are diffs
   if [ -s $pwd/work/v-diff/$tag.diff ] ;then
      echo "Tag $tag -> Not identical."
      echo "Tag $tag -> Not identical." >> diff.log
   else
      echo "Tag $tag -> Identical."
      echo "Tag $tag -> Identical." >> diff.log
   fi
done
